/*
 * Copyright 2021 Fluence Labs Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

use crate::traits::RecordResolvableError;

use it_memory_traits::MemoryAccessError;

use thiserror::Error as ThisError;

#[derive(Debug, ThisError)]
pub enum LiError {
    #[error("{0}")]
    MemoryAccessError(#[from] MemoryAccessError),

    #[error("{0}")]
    RecordResolvableError(#[from] RecordResolvableError),

    #[error("{0}")]
    InvalidUTF8String(#[from] std::string::FromUtf8Error),

    /// This error occurred when a record is created from empty values array.
    #[error("Record with name '{0}' can't be empty")]
    EmptyRecord(String),
}
